@@ -2,7 +2,7 @@
 #include "message.h"
 
 
-Message::Message(long length, const char * data)
+Message::Message(unsigned long length, const char * data)
 {
   memorySize=length;
   memory = boost::shared_array<char>(new char[memorySize]);
@@ -38,7 +38,7 @@ Message::~Message()
 }
 
 
-void Message::setMessage(long length, const char * data)
+void Message::setMessage(unsigned long length, const char * data)
 {
   memorySize=length;
   memory = boost::shared_array<char>(new char[memorySize]);
@@ -67,7 +67,7 @@ const char * Message::getDataPtr() const
 }
 
 
-long Message::size() const
+unsigned long Message::size() const
 {
   return endIndex-startIndex;
 }
@@ -83,13 +83,9 @@ void Message::clear()
 }
 
 
-const char & Message::operator [] (long idx)
+const char & Message::operator [] (unsigned long idx)
 {
-  long localidx=startIndex+idx;
-  if (localidx<0)
-  {
-    throw MessageException("Message::operator[] failed, localidx<0");
-  }
+  unsigned long localidx=startIndex+idx;
   if (localidx>=memorySize)
   {
     throw MessageException("Message::operator[] failed, localidx>=memorySize");
@@ -143,10 +139,10 @@ void Message::pushBackMemory(const void *src, size_t n)
     {
       increment=n;
     }
-    long newMemorySize=memorySize+increment;
+    unsigned long newMemorySize=memorySize+increment;
     boost::shared_array<char>  newMemory(new char[newMemorySize]);
-    long newStartIndex=startIndex;
-    long newEndIndex=endIndex;
+    unsigned long newStartIndex=startIndex;
+    unsigned long newEndIndex=endIndex;
     memcpy(&newMemory[newStartIndex], &memory[startIndex], endIndex-startIndex);
 
     memorySize=newMemorySize;
@@ -189,10 +185,10 @@ void Message::popFrontMemory(void *dest, size_t n)
     // shrink memory
     if (startIndex>=STANDARDBUFFERINCREMENT)
     {
-      long newMemorySize=memorySize-STANDARDBUFFERINCREMENT;
+      unsigned long newMemorySize=memorySize-STANDARDBUFFERINCREMENT;
       boost::shared_array<char>  newMemory(new char[newMemorySize]);
-      long newStartIndex=startIndex-STANDARDBUFFERINCREMENT;
-      long newEndIndex=endIndex-STANDARDBUFFERINCREMENT;
+      unsigned long newStartIndex=startIndex-STANDARDBUFFERINCREMENT;
+      unsigned long newEndIndex=endIndex-STANDARDBUFFERINCREMENT;
       memcpy(&newMemory[newStartIndex], &memory[startIndex], endIndex-startIndex);
 
       memorySize=newMemorySize;
