@@ -23,25 +23,25 @@ class Message
 {
 private:
   boost::shared_array<char> memory;
-  long memorySize;  // size of allocated memory
+  unsigned long memorySize;  // size of allocated memory
   unsigned long startIndex;  // memory[startIndex] is the first valid byte
   unsigned long endIndex;    // memory[endIndex]   is the byte AFTER the last valid byte
 
 
 public:
-  Message(long length=STANDARDBUFFERSIZE, const char * data=0);
+  Message(unsigned long length=STANDARDBUFFERSIZE, const char * data=0);
   Message(const Message& message);
   ~Message();
 
   bool dontSendFlag;
 
-  void setMessage(long length, const char * data);
+  void setMessage(unsigned long length, const char * data);
 
   Message & operator= (const Message & message);
-  const char & operator [] (long idx);
+  const char & operator [] (unsigned long idx);
 
   const char * getDataPtr() const;
-  long size() const;
+  unsigned long size() const;
   void clear();
 
   void pushFrontMemory(const void *src, size_t n);
@@ -50,4 +50,4 @@ public:
 };
 
 
-#endif
+#endif // _message_h
