@@ -65,4 +65,5 @@ void pushFront(Message & message, const float64 & value);
 void popFront(Message & message, float64 & returnValue);
 }
 
-#endif
+
+#endif // _messagebasictypes_h
