@@ -14,4 +14,5 @@ void pushFront(Message & message, const std::string & value);
 void popFront(Message & message, std::string & returnValue);
 }
 
-#endif
+
+#endif // _messagecomplextypes_h
