@@ -6,4 +6,4 @@ enum { maxMessageIOSize = 65535 }; // maximum message size to handle (without ov
 enum { maxSendQueueSize = 500 }; // maximum number of messages in queues; drop messages if exceeded
 
 
-#endif
+#endif // _messageioconst_h
