@@ -108,7 +108,7 @@ void TCPMessageClient::queueAndSendMessageSlot(Message & message)
 
 void TCPMessageClient::startNewTransmission()
 {
-  if ((false==sendQueueCurrentlySending) && (sendQueue.size()>0))
+  if ((false==sendQueueCurrentlySending) && (!sendQueue.empty()))
   {
     Message & message=sendQueue.front();
     sendQueueCurrentlySending=true;
