@@ -4,7 +4,7 @@
 
 #include <boost/asio.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "messageclient.h"
 
 // class TCPMessageClient
@@ -22,10 +22,11 @@ class TCPMessageClient : public MessageClient
 private:
   boost::asio::io_service & ioservice;
 
+  boost::asio::deadline_timer timer;
+
   boost::asio::ip::tcp::resolver resolver;
   boost::asio::ip::tcp::socket socket;
 
-  boost::asio::deadline_timer timer;
 
   unsigned long messageSize;
   char data[maxMessageIOSize];
@@ -54,5 +55,4 @@ public:
 };
 
 
-#endif
-
+#endif // _tcpmessageclient_h
