@@ -2,7 +2,7 @@
 #include <boost/bind.hpp>
 
 
-TCPMessageServer::TCPMessageServer(asio::io_service& io_service, const asio::ip::tcp::endpoint & endpoint, ServerConnectorFactoryBase & serverConnectorFactoryBase)
+TCPMessageServer::TCPMessageServer(boost::asio::io_service& io_service, const boost::asio::ip::tcp::endpoint & endpoint, ServerConnectorFactoryBase & serverConnectorFactoryBase)
   : ioservice(io_service),
     acceptor(ioservice),
     serverConnectorFactoryBase(serverConnectorFactoryBase),
@@ -14,13 +14,13 @@ TCPMessageServer::TCPMessageServer(asio::io_service& io_service, const asio::ip:
   acceptor.open(endpoint.protocol());
   if (endpoint.address().is_v6())
   {
-    acceptor.set_option(asio::ip::v6_only(true));
+    acceptor.set_option(boost::asio::ip::v6_only(true));
   }
-  acceptor.set_option(asio::ip::tcp::acceptor::reuse_address(true));
+  acceptor.set_option(boost::asio::ip::tcp::acceptor::reuse_address(true));
   acceptor.bind(endpoint);
   acceptor.listen();
   acceptor.async_accept(newConnection->socket(),
-                        boost::bind(&TCPMessageServer::handleAccept, this, asio::placeholders::error));
+                        boost::bind(&TCPMessageServer::handleAccept, this, boost::asio::placeholders::error));
 }
 
 
@@ -42,7 +42,7 @@ void TCPMessageServer::stop()
 }
 
 
-void TCPMessageServer::handleAccept(const asio::error_code& e)
+void TCPMessageServer::handleAccept(const boost::system::error_code& e)
 {
   if (!e)
   {
@@ -52,7 +52,7 @@ void TCPMessageServer::handleAccept(const asio::error_code& e)
 
     acceptor.async_accept(newConnection->socket(),
                           boost::bind(&TCPMessageServer::handleAccept, this,
-                                      asio::placeholders::error));
+                                      boost::asio::placeholders::error));
   }
 }
 
