@@ -31,4 +31,4 @@ public:
 };
 
 
-#endif
+#endif // _tcpmessageserver_h
