@@ -2,7 +2,7 @@
 #define _udpmessagereceiver_h
 
 #include <boost/asio.hpp>
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "message.h"
 #include "messageioconst.h"
 
@@ -23,8 +23,8 @@ public:
   UDPMessageReceiver(boost::asio::io_service& io_service, const boost::asio::ip::udp::endpoint & listenEndpoint,
                      const boost::asio::ip::address& multicast_address);
 
-  boost::signal<void (Message & message)> receiveMessageSignal;
+  boost::signals2::signal<void (Message & message)> receiveMessageSignal;
 };
 
 
-#endif
+#endif // _udpmessagereceiver_h
