@@ -3,24 +3,24 @@
 
 
 
-UDPMessageServer::UDPMessageServer(asio::io_service& io_service, const asio::ip::udp::endpoint & endpoint )
+UDPMessageServer::UDPMessageServer(boost::asio::io_service& io_service, const boost::asio::ip::udp::endpoint & endpoint )
   :ioservice(io_service),
    sock(io_service)
 {
   sock.open(endpoint.protocol());
   if (endpoint.address().is_v6())
   {
-    sock.set_option(asio::ip::v6_only(true));
+    sock.set_option(boost::asio::ip::v6_only(true));
   }
   sock.bind(endpoint);
 
-  sock.async_receive_from( asio::buffer(data, maxMessageIOSize), sender_endpoint,
-                           boost::bind(&UDPMessageServer::handleReceiveFrom, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+  sock.async_receive_from( boost::asio::buffer(data, maxMessageIOSize), sender_endpoint,
+                           boost::bind(&UDPMessageServer::handleReceiveFrom, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
 
 }
 
 
-void UDPMessageServer::handleReceiveFrom(const asio::error_code& err, size_t length)
+void UDPMessageServer::handleReceiveFrom(const boost::system::error_code& err, size_t length)
 {
   if (err)
   {
@@ -38,11 +38,11 @@ void UDPMessageServer::handleReceiveFrom(const asio::error_code& err, size_t len
     if ((false==returnMessage.dontSendFlag) && (returnMessage.size()>0) && (returnMessage.size()<=maxMessageIOSize))
     {
       //cout << "UDPMessageServer::handle_receive_from sending " << returnMessage.size() << " bytes" << endl;
-      sock.send_to(asio::buffer(returnMessage.getDataPtr(), returnMessage.size()), sender_endpoint);
+      sock.send_to(boost::asio::buffer(returnMessage.getDataPtr(), returnMessage.size()), sender_endpoint);
     }
 
-    sock.async_receive_from( asio::buffer(data, maxMessageIOSize), sender_endpoint,
-                             boost::bind(&UDPMessageServer::handleReceiveFrom, this, asio::placeholders::error, asio::placeholders::bytes_transferred));
+    sock.async_receive_from( boost::asio::buffer(data, maxMessageIOSize), sender_endpoint,
+                             boost::bind(&UDPMessageServer::handleReceiveFrom, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
 
   }
 }
