@@ -1,11 +1,11 @@
 #ifndef _messageserver_h
 #define _messageserver_h
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "message.h"
 
 
-typedef boost::signal<void (Message & returnMessage, Message & message)>  ReceiveMessageSignal;
+typedef boost::signals2::signal<void (Message & returnMessage, Message & message)>  ReceiveMessageSignal;
 
 
 class MessageServer
@@ -15,4 +15,4 @@ public:
 };
 
 
-#endif
+#endif // _messageserver_h
