@@ -2,15 +2,15 @@
 #define _serverconnectorbase_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "message.h"
 
 class ServerConnectorBase
 {
 public:
-  boost::signal<void (Message message)>  sendMessageSignal;
+  boost::signals2::signal<void (Message message)>  sendMessageSignal;
   virtual void receiveMessageSlot(Message message)=0;
 };
 
 
-#endif
+#endif // _serverconnectorbase_h
