@@ -14,4 +14,5 @@ public:
   virtual boost::shared_ptr<ServerConnectorBase> createServerConnector()=0;
 };
 
-#endif
+
+#endif // _serverconnectorfactorybase_h
