@@ -18,7 +18,7 @@ void CompositeParser::parse(Message & returnMessage, Message & message)
 
   // find will return an iterator to the matching element if it is found
   // or to the end of the map if the key is not found
-  mapType::iterator iter = myMap.find(messageID);
+  mapType::const_iterator iter = myMap.find(messageID);
   if ( iter != myMap.end() )
   {
     iter->second.sPtr->parse(returnMessage, message);
