@@ -2,7 +2,7 @@
 #define _templateparser_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "parser.h"
 
 
@@ -11,7 +11,7 @@
 class TemplateParser_0ret_0 : public Parser
 {
 public:
-  boost::signal<void ()> callWorkerSignal;
+  boost::signals2::signal<void ()> callWorkerSignal;
 
   void parse(Message & /*returnMessage*/, Message & /*message*/)
   {
@@ -24,7 +24,7 @@ template<typename T1>
 class TemplateParser_0ret_1 : public Parser
 {
 public:
-  boost::signal<void (const T1&)> callWorkerSignal;
+  boost::signals2::signal<void (const T1&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -40,7 +40,7 @@ template<typename T1ret>
 class TemplateParser_1ret_0 : public Parser
 {
 public:
-  boost::signal<void (T1ret&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & /*message*/)
   {
@@ -56,7 +56,7 @@ template<typename T1ret, typename T1>
 class TemplateParser_1ret_1 : public Parser
 {
 public:
-  boost::signal<void (T1ret&, const T1&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, const T1&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -77,7 +77,7 @@ template<typename T1ret, typename T1, typename T2>
 class TemplateParser_1ret_2 : public Parser
 {
 public:
-  boost::signal<void (T1ret&, const T1&, const T2&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, const T1&, const T2&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -100,7 +100,7 @@ template<typename T1ret, typename T2ret>
 class TemplateParser_2ret_0: public Parser
 {
 public:
-  boost::signal<void (T1ret&, T2ret&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, T2ret&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & /*message*/)
   {
@@ -119,7 +119,7 @@ template<typename T1ret, typename T2ret, typename T1>
 class TemplateParser_2ret_1: public Parser
 {
 public:
-  boost::signal<void (T1ret&, T2ret&, const T1&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, T2ret&, const T1&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -141,7 +141,7 @@ template<typename T1ret, typename T2ret, typename T1, typename T2>
 class TemplateParser_2ret_2: public Parser
 {
 public:
-  boost::signal<void (T1ret&, T2ret&, const T1&, const T2&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, T2ret&, const T1&, const T2&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -165,7 +165,7 @@ template<typename T1ret, typename T2ret, typename T3ret, typename T1>
 class TemplateParser_3ret_1: public Parser
 {
 public:
-  boost::signal<void (T1ret&, T2ret&, T3ret&, const T1&)> callWorkerSignal;
+  boost::signals2::signal<void (T1ret&, T2ret&, T3ret&, const T1&)> callWorkerSignal;
 
   void parse(Message & returnMessage, Message & message)
   {
@@ -184,4 +184,5 @@ public:
   }
 };
 
-#endif
+
+#endif // _templateparser_h
