@@ -2,14 +2,14 @@
 #define _templatereplyparser_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "replyparser.h"
 
 
 class TemplateReplyParser_0 : public ReplyParser
 {
 public:
-  boost::signal<void ()> callWorkerSignal;
+  boost::signals2::signal<void ()> callWorkerSignal;
 
   void parse(Message & /*replyMessage*/)
   {
@@ -22,7 +22,7 @@ template<typename T1>
 class TemplateReplyParser_1 : public ReplyParser
 {
 public:
-  boost::signal<void (const T1&)> callWorkerSignal;
+  boost::signals2::signal<void (const T1&)> callWorkerSignal;
 
   void parse(Message & replyMessage)
   {
@@ -38,7 +38,7 @@ template<typename T1, typename T2>
 class TemplateReplyParser_2 : public ReplyParser
 {
 public:
-  boost::signal<void (const T1&, const T2&)> callWorkerSignal;
+  boost::signals2::signal<void (const T1&, const T2&)> callWorkerSignal;
 
   void parse(Message & replyMessage)
   {
@@ -56,7 +56,7 @@ template<typename T1, typename T2, typename T3>
 class TemplateReplyParser_3 : public ReplyParser
 {
 public:
-  boost::signal<void (const T1&, const T2&, const T3&)> callWorkerSignal;
+  boost::signals2::signal<void (const T1&, const T2&, const T3&)> callWorkerSignal;
 
   void parse(Message & replyMessage)
   {
@@ -72,4 +72,4 @@ public:
 };
 
 
-#endif
+#endif // _templatereplyparser_h
