@@ -1,4 +1,6 @@
 #include "protocoltimer.h"
+#include "protocolio.h"
+#include "thetimerobjectbase.h"
 
 
 ProtocolTimer::ProtocolTimer(ProtocolIO & protocolIO) : theTimerObjectBase(protocolIO.getTimer())
@@ -9,11 +11,8 @@ ProtocolTimer::ProtocolTimer(ProtocolIO & protocolIO) : theTimerObjectBase(proto
 
 ProtocolTimer::~ProtocolTimer()
 {
-  if (myHandlerBase)
-  {
-    delete myHandlerBase;
-    myHandlerBase=0;
-  }
+  delete myHandlerBase;
+  myHandlerBase=0;
   delete theTimerObjectBase;
 }
 
@@ -21,9 +20,6 @@ ProtocolTimer::~ProtocolTimer()
 void ProtocolTimer::stop()
 {
   theTimerObjectBase->stop();
-  if (myHandlerBase)
-  {
-    delete myHandlerBase;
-    myHandlerBase=0;
-  }
+  delete myHandlerBase;
+  myHandlerBase=0;
 }
