@@ -18,4 +18,4 @@ public:
 };
 
 
-#endif
+#endif // _rpcserverconnector_h
