@@ -8,4 +8,4 @@
 bool getCpuinfo(Cpuinfo & cpuinfo);
 
 
-#endif
+#endif // _cpuinfometer_h
