@@ -21,4 +21,4 @@ public:
 };
 
 
-#endif
+#endif // _cpustatmeter_h
