@@ -3,7 +3,9 @@
 
 Deriver::Deriver()
 {
+  lastValue=0.;
   lastIsValid=false;
+  currentValue=0.;
   currentIsValid=false;
 }
 
