@@ -18,4 +18,5 @@ public:
   bool getDiskload(Diskload & diskload);
 };
 
-#endif
+
+#endif // _diskloadmeter_h
