@@ -8,4 +8,4 @@
 bool getLoadavg(Loadavg & loadavg);
 
 
-#endif
+#endif // _loadavgmeter_h
