@@ -6,4 +6,5 @@
 
 bool getMeminfo(Meminfo & meminfo);
 
-#endif
+
+#endif // _meminfometer_h
