@@ -23,9 +23,10 @@ private:
 
 
 public:
-  NetloadMeter(const std::string _iface ="");
+  NetloadMeter(const std::string & _iface ="");
 
   bool getNetload(Netload & netload);
 };
 
-#endif
+
+#endif // _netloadmeter_h
