@@ -6,4 +6,5 @@
 
 Unameinfo getUnameinfo();
 
-#endif
+
+#endif // _unamemeter_h
