@@ -8,4 +8,4 @@
 bool getUptime(Uptime & uptime);
 
 
-#endif
+#endif // _uptimemeter_h
