@@ -9,4 +9,4 @@ struct Cpuinfo
 };
 
 
-#endif
+#endif // _cpuinfo_h
