@@ -14,4 +14,4 @@ struct Cpustat
 };
 
 
-#endif
+#endif // _cpustat_h
