@@ -9,4 +9,4 @@ struct Diskload
 };
 
 
-#endif
+#endif // _diskload_h
