@@ -9,4 +9,4 @@ struct Loadavg
 };
 
 
-#endif
+#endif // _loadavg_h
