@@ -14,4 +14,4 @@ struct Netload
 };
 
 
-#endif
+#endif // _netload_h
