@@ -18,4 +18,5 @@ struct Procinfo
 
 typedef std::list < Procinfo > ProcinfoList;
 
-#endif
+
+#endif // _procinfo_h
