@@ -57,4 +57,5 @@ struct Wsinfo
 
 bool operator<(const Wsinfo& a, const Wsinfo& b);
 
-#endif
+
+#endif // _sinfo_h
