@@ -4,8 +4,8 @@ using namespace std;
 
 bool stringAndNumericLessThan(const string & a, const string & b)
 {
-  long aidx=0;
-  long bidx=0;
+  unsigned long aidx=0;
+  unsigned long bidx=0;
   while ((aidx<a.size()) && (bidx<b.size()))
   {
     if ( (0!=isdigit(a[aidx])) && (0!=isdigit(b[bidx])) )
