@@ -7,4 +7,5 @@
 
 bool stringAndNumericLessThan(const std::string & a, const std::string & b);
 
-#endif
+
+#endif // _stringandnumericcomparison_h
