@@ -13,4 +13,5 @@ struct Unameinfo
   std::string machine;
 };
 
-#endif
+
+#endif // _uname_h
