@@ -4,14 +4,14 @@
 /*******************************************************************************
 ** File gererated from sinfo.idlx
 **
-** Created: Sun Jul  8 08:47:26 2012
+** Created: Tue Dec 16 15:03:43 2014
 **      by: idlxcompiler version 0.0.1
 **
 ** WARNING!
 ** All changes made in this file will be lost when recompiling idlx file.
 *******************************************************************************/
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "messagesinfotypes.h"
 #include "replyparser.h"
 
@@ -23,7 +23,7 @@ public:
   void getSinfoListRequest();
   void getFilteredSinfoListRequest(const std::string & filterMarker);
 
-  boost::signal<void (Message & message)> sinfoClientRequestMessageSignal;
+  boost::signals2::signal<void (Message & message)> sinfoClientRequestMessageSignal;
 };
 
 
