@@ -321,7 +321,7 @@ void SinfoCurses:: printInteractiveOneHost(int maxy, int maxx, int & y, int & x,
     for (plit=wsinfo.procinfoList.begin();
          plit!=wsinfo.procinfoList.end()
          && ((ii < config.listtop) || (config.ownprocesses));
-         plit++, ii++)
+         ++plit, ++ii)
     {
       bool own = false;
       if ( (config.username.size()>0) && (plit->username == config.username) )
@@ -334,7 +334,7 @@ void SinfoCurses:: printInteractiveOneHost(int maxy, int maxx, int & y, int & x,
       bool ignore = false;
       for (list < string > ::iterator it = config.ignoreList.begin();
            it != config.ignoreList.end();
-           it++)
+           ++it)
       {
         if ( plit->command == (*it) )
         {
@@ -471,7 +471,7 @@ void SinfoCurses::printAll()
 
     // one line for the header... two lines are default for each node
     y -= 1 + wsinfoList.size() * 2;
-    if ((y < int(wsinfoList.size())) || (wsinfoList.size() == 0))
+    if ((y < int(wsinfoList.size())) || (wsinfoList.empty()))
       config.listtop = 1;
     else
       config.listtop = y / wsinfoList.size();
@@ -500,7 +500,7 @@ void SinfoCurses::printAll()
   printInteractiveStatusLine(cpuCount, speedUsed, speedSum);
   for (list < Wsinfo > ::iterator it = wsinfoList.begin();
        it != wsinfoList.end();
-       it++)
+       ++it)
     printInteractiveOneHost(maxy, maxx, y, x, colormode, *it, speedMin, speedMax);
 
   wattrset(win, A_NORMAL);
