@@ -20,7 +20,7 @@ void SinfoData::calcSpeedInfo(long & cpuCount, float & speedSum, float & speedUs
 
   for (list < Wsinfo > ::iterator it = wsinfoList.begin();
        it != wsinfoList.end();
-       it++)
+       ++it)
   {
     cpuCount+=it->cpuinfo.cpus;
     if (it->cpuinfo.cpus * it->cpuinfo.speedmhz > speedMax)
@@ -43,10 +43,10 @@ void SinfoData::calcSpeedInfo(long & cpuCount, float & speedSum, float & speedUs
 
 long SinfoData::getProcinfoListMax()
 {
-  long procinfoListMax=0;
+  unsigned long procinfoListMax=0;
   for (list < Wsinfo > ::iterator it = wsinfoList.begin();
        it != wsinfoList.end();
-       it++)
+       ++it)
   {
     if (it->procinfoList.size()>procinfoListMax)
     {
