@@ -2,7 +2,7 @@
 #define _sinfodata_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 #include <list>
 #include "sinfo.h"
@@ -19,8 +19,8 @@ public:
   void calcSpeedInfo(long & cpuCount, float & speedSum, float & speedUsed, float & speedMin, float & speedMax);
   long getProcinfoListMax();
 
-  boost::signal<void ()> changedSignal;
+  boost::signals2::signal<void ()> changedSignal;
 };
 
 
-#endif
+#endif // _sinfodata_h
