@@ -28,4 +28,4 @@ public:
 };
 
 
-#endif
+#endif // _sinfohtml_h
