@@ -12,4 +12,4 @@ void sinfoPrintHostsAndIP(std::list < Wsinfo > & wsinfoList, bool systeminfo);
 void sinfoPrintHostsLoad(std::list < Wsinfo > & wsinfoList, bool systeminfo, bool quiet);
 
 
-#endif
+#endif // _sinfoprint_h
