@@ -7,7 +7,7 @@ using namespace Msg;
 
 
 SinfoRequester::SinfoRequester(ProtocolIO & protocolIO, SinfoData & _sinfoData)
-  : waitForConnectionReadyTimer(protocolIO), periodicRequestTimer(protocolIO), requestUpdateTimer(protocolIO), sinfoData(_sinfoData)
+  : sinfoData(_sinfoData), waitForConnectionReadyTimer(protocolIO), requestUpdateTimer(protocolIO), periodicRequestTimer(protocolIO)
 {
   delay_millisec=1000;
   timeout_millisec=1000;
@@ -102,7 +102,8 @@ void SinfoRequester::receivedMessageSlot(Message & returnMessage)
     {
       uint8 messageID;
       popFrontuint8(returnMessage,messageID);
-      if (2!=messageID) return;
+      if (2!=messageID)
+        return;
 
       //cout << "messageID=" << int(messageID) << endl;
       compositeReplyParser.parse(returnMessage);
