@@ -2,7 +2,7 @@
 #define _sinforequester_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "sinfodata.h"
 #include "protocoltimer.h"
 #include "sinfo.idlx.client.h"
@@ -40,10 +40,10 @@ public:
 
   void connectionReadySlot();
   void receivedMessageSlot(Message & returnMessage);
-  boost::signal<void ()> timeoutSignal;
+  boost::signals2::signal<void ()> timeoutSignal;
 
-  boost::signal<void (Message & message)> queueAndSendMessageSignal;
+  boost::signals2::signal<void (Message & message)> queueAndSendMessageSignal;
 };
 
 
-#endif
+#endif // _sinforequester_h
