@@ -29,4 +29,4 @@ public:
 };
 
 
-#endif
+#endif // _sinfoviewconfig_h
