@@ -27,4 +27,4 @@ public:
 };
 
 
-#endif
+#endif // _broadcastreceiver_h
