@@ -6,7 +6,7 @@ using namespace std;
 
 
 // delete workstations from sinfod's buffer if they were not heard for 300 seconds
-const unsigned long deleteoldTimer = 300;
+const long deleteoldTimer = 300;
 
 
 
@@ -29,7 +29,9 @@ void CleanupList::timerEvent()
       it = wsinfoList.erase(it);
     }
     else
-      it++;
+    {
+      ++it;
+    }
   }
 }
 
