@@ -24,6 +24,4 @@ public:
 };
 
 
-#endif
-
-
+#endif // _cleanuplist_h
