@@ -4,4 +4,4 @@
 void demoninit();
 
 
-#endif
+#endif // _demoninit_h
