@@ -2,7 +2,7 @@
 #define _lastgasp_h
 
 
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 #include "message.h"
 
 
@@ -12,8 +12,8 @@ public:
   LastGasp();
   ~LastGasp();
 
-  boost::signal<void (Message&)> sendMessageSignal;
+  boost::signals2::signal<void (Message&)> sendMessageSignal;
 };
 
 
-#endif
+#endif // _lastgasp_h
