@@ -56,7 +56,7 @@ const unsigned long markerTimer = 900;
 const unsigned long restartTimer = 10;
 
 
-MeasureServer::MeasureServer(boost::asio::io_service& io_service, const std::string & networkcard, const std::string & _marker, bool cmdlinemode, std::list < std::string > ignoreList, long listtop):ioservice(io_service), timer(io_service), netloadMeter(networkcard), marker(_marker), procinfoMeter(cmdlinemode,ignoreList), listtop(listtop)
+MeasureServer::MeasureServer(boost::asio::io_service& io_service, const std::string & networkcard, const std::string & _marker, bool cmdlinemode, std::list < std::string > ignoreList, long listtop):ioservice(io_service), timer(io_service), procinfoMeter(cmdlinemode,ignoreList), listtop(listtop),  netloadMeter(networkcard), marker(_marker)
 {
   timeCounter = 0;
   procinfonow = false;
