@@ -7,7 +7,7 @@
 #include "netloadmeter.h"
 #include "diskloadmeter.h"
 #include "procinfometer.h"
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
 
 
 class MeasureServer
@@ -41,11 +41,10 @@ public:
   void timerEvent();
   void restartCounterEvent();
 
-  boost::signal<void (Message&)> sendMeasurementSignal;
+  boost::signals2::signal<void (Message&)> sendMeasurementSignal;
 
   void handle_timeout(); // asio part
 };
 
 
-#endif
-
+#endif // _measureserver_h
