@@ -19,5 +19,4 @@ enum SinfoBroadcastIDs
 };
 
 
-
-#endif
+#endif // _sinfobroadcastids_h
