@@ -7,17 +7,17 @@ SinfoWorker::SinfoWorker(std::list < Wsinfo > & wsinfoList) : wsinfoList(wsinfoL
 }
 
 
-void SinfoWorker::getSinfoList(std::list < Wsinfo > & returnWsinfoList)
+void SinfoWorker::getSinfoList(std::list < Wsinfo > & returnWsinfoList) const
 {
   returnWsinfoList=wsinfoList; // this is a copy to returnWsinfoList
 }
 
 
-void SinfoWorker::getFilteredSinfoList( std::list < Wsinfo > & returnWsinfoList, const string & filterMarker)
+void SinfoWorker::getFilteredSinfoList( std::list < Wsinfo > & returnWsinfoList, const string & filterMarker) const
 {
   for (std::list < Wsinfo > ::iterator wit = wsinfoList.begin();
        wit != wsinfoList.end();
-       wit++)
+       ++wit)
   {
     if ((*wit).marker == filterMarker)
     {
