@@ -14,9 +14,9 @@ private:
 public:
   SinfoWorker(std::list < Wsinfo > & wsinfoList);
 
-  void getSinfoList( std::list < Wsinfo > & returnWsinfoList);
-  void getFilteredSinfoList( std::list < Wsinfo > & returnWsinfoList, const std::string & filterMarker);
+  void getSinfoList( std::list < Wsinfo > & returnWsinfoList) const;
+  void getFilteredSinfoList( std::list < Wsinfo > & returnWsinfoList, const std::string & filterMarker) const;
 };
 
 
-#endif
+#endif // _sinfoworker_h
